@@ -681,20 +681,32 @@ EXPORT StringBuf uri_to_display(const char * uri)
 #undef URI_PREFIX
 #undef URI_PREFIX_LEN
 
+static const char * parse_subtune(const char * str, int * isub_p)
+{
+    const char * c = strrchr(str, '?');
+    int isub = 0;
+    char junk;
+
+    if (c && sscanf(c + 1, "%d%c", &isub, &junk) != 1)
+        c = nullptr;
+    if (isub_p)
+        *isub_p = isub;
+
+    return c;
+}
+
 EXPORT void uri_parse(const char * uri, const char ** base_p,
                       const char ** ext_p, const char ** sub_p, int * isub_p)
 {
     const char * end = uri + strlen(uri);
     const char *base, *ext, *sub, *c;
-    int isub = 0;
-    char junk;
 
     if ((c = strrchr(uri, '/')))
         base = c + 1;
     else
         base = end;
 
-    if ((c = strrchr(base, '?')) && sscanf(c + 1, "%d%c", &isub, &junk) == 1)
+    if ((c = parse_subtune(base, isub_p)))
         sub = c;
     else
         sub = end;
@@ -710,8 +722,6 @@ EXPORT void uri_parse(const char * uri, const char ** base_p,
         *ext_p = ext;
     if (sub_p)
         *sub_p = sub;
-    if (isub_p)
-        *isub_p = isub;
 }
 
 EXPORT StringBuf uri_get_scheme(const char * uri)
@@ -751,7 +761,9 @@ EXPORT StringBuf uri_get_display_base(const char * uri)
  *     a. a full URI (returned unchanged)
  *     b. an absolute filename (in UTF-8 or the system locale)
  *     c. a relative path (character set detected according to user settings)
- *   2. reference: the full URI of the playlist containing <path> */
+ *   2. reference: the full URI of the playlist containing <path>
+ *
+ * Valid subtune suffixes such as '?3' are preserved. */
 
 EXPORT StringBuf uri_construct(const char * path, const char * reference)
 {
@@ -759,28 +771,46 @@ EXPORT StringBuf uri_construct(const char * path, const char * reference)
     if (strstr(path, "://"))
         return str_copy(path);
 
-        /* absolute filename */
+    StringBuf buf;
+    auto sub = parse_subtune(path, nullptr);
+    if (sub)
+    {
+        /* split out subtune suffix so it isn't percent-encoded */
+        buf = str_copy(path, sub - path);
+        path = buf;
+    }
+
 #ifdef _WIN32
     if (path[0] && path[1] == ':' && IS_SEP(path[2]))
 #else
     if (path[0] == '/')
 #endif
-        return filename_to_uri(path);
+    {
+        /* absolute filename */
+        buf = filename_to_uri(path);
+    }
+    else
+    {
+        /* relative path */
+        const char * slash = strrchr(reference, '/');
+        if (!slash)
+            return StringBuf();
 
-    /* relative path */
-    const char * slash = strrchr(reference, '/');
-    if (!slash)
-        return StringBuf();
+        buf = str_to_utf8(path, -1);
+        if (!buf)
+            return StringBuf();
 
-    StringBuf buf = str_to_utf8(path, -1);
-    if (!buf)
-        return StringBuf();
+        if (aud_get_bool("convert_backslash"))
+            str_replace_char(buf, '\\', '/');
 
-    if (aud_get_bool("convert_backslash"))
-        str_replace_char(buf, '\\', '/');
+        buf = str_encode_percent(buf);
+        buf.insert(0, reference, slash + 1 - reference);
+    }
+
+    /* re-add subtune suffix */
+    if (sub)
+        buf.insert(-1, sub);
 
-    buf = str_encode_percent(buf);
-    buf.insert(0, reference, slash + 1 - reference);
     return buf.settle();
 }
 
