@@ -26,26 +26,26 @@
 class PluginHandle;
 class Tuple;
 
-void output_init ();
-void output_cleanup ();
+void output_init();
+void output_cleanup();
 
-bool output_open_audio (const String & filename, const Tuple & tuple,
- int format, int rate, int channels, int start_time);
-void output_set_tuple (const Tuple & tuple);
-void output_set_replay_gain (const ReplayGainInfo & info);
-bool output_write_audio (const void * data, int size, int stop_time);
-void output_flush (int time, bool force = false);
-void output_resume ();
-void output_pause (bool pause);
+bool output_open_audio(const String & filename, const Tuple & tuple, int format,
+                       int rate, int channels, int start_time, bool pause);
+void output_set_tuple(const Tuple & tuple);
+void output_set_replay_gain(const ReplayGainInfo & info);
+bool output_write_audio(const void * data, int size, int stop_time);
+void output_flush(int time, bool force = false);
+void output_resume();
+void output_pause(bool pause);
 
-int output_get_time ();
-int output_get_raw_time ();
-void output_close_audio ();
-void output_drain ();
+int output_get_time();
+int output_get_raw_time();
+void output_close_audio();
+void output_drain();
 
-PluginHandle * output_plugin_get_current ();
-PluginHandle * output_plugin_get_secondary ();
-bool output_plugin_set_current (PluginHandle * plugin);
-bool output_plugin_set_secondary (PluginHandle * plugin);
+PluginHandle * output_plugin_get_current();
+PluginHandle * output_plugin_get_secondary();
+bool output_plugin_set_current(PluginHandle * plugin);
+bool output_plugin_set_secondary(PluginHandle * plugin);
 
 #endif
