@@ -30,30 +30,32 @@ class VFSFile;
 /* ====== ALBUM ART API ====== */
 
 /* request format */
-enum {
-    AUD_ART_DATA = (1 << 0),  /* image data in memory */
-    AUD_ART_FILE = (1 << 1)   /* filename of image data on disk */
+enum
+{
+    AUD_ART_DATA = (1 << 0), /* image data in memory */
+    AUD_ART_FILE = (1 << 1)  /* filename of image data on disk */
 };
 
 /* opaque type storing art data */
 struct AudArtItem;
 
 /* don't use these directly, use AudArtPtr */
-const Index<char> * aud_art_data (const AudArtItem * item);
-const char * aud_art_file (const AudArtItem * item);
-void aud_art_unref (AudArtItem * item);
+const Index<char> * aud_art_data(const AudArtItem * item);
+const char * aud_art_file(const AudArtItem * item);
+void aud_art_unref(AudArtItem * item);
 
 /* handle for accessing/tracking album art data */
 class AudArtPtr : public SmartPtr<AudArtItem, aud_art_unref>
 {
 public:
-    AudArtPtr () : SmartPtr () {}
-    explicit AudArtPtr (AudArtItem * ptr) : SmartPtr (ptr) {}
+    AudArtPtr() : SmartPtr() {}
+    explicit AudArtPtr(AudArtItem * ptr) : SmartPtr(ptr) {}
 
-    const Index<char> * data () const
-        { return get () ? aud_art_data (get ()) : nullptr; }
-    const char * file () const
-        { return get () ? aud_art_file (get ()) : nullptr; }
+    const Index<char> * data() const
+    {
+        return get() ? aud_art_data(get()) : nullptr;
+    }
+    const char * file() const { return get() ? aud_art_file(get()) : nullptr; }
 };
 
 /*
@@ -71,22 +73,25 @@ public:
  *
  * On error, a null pointer is returned and *queued is set to false.
  */
-AudArtPtr aud_art_request (const char * file, int format, bool * queued = nullptr);
+AudArtPtr aud_art_request(const char * file, int format,
+                          bool * queued = nullptr);
 
 /* ====== GENERAL PROBING API ====== */
 
 /* The following two functions take an additional VFSFile parameter to allow
  * opening a file, probing for a decoder, and then reading the song metadata
  * without opening the file a second time.  If you don't already have a file
- * handle open, then just pass in a null VFSFile and it will be opened for you. */
-PluginHandle * aud_file_find_decoder (const char * filename, bool fast,
- VFSFile & file, String * error = nullptr);
-bool aud_file_read_tag (const char * filename, PluginHandle * decoder,
- VFSFile & file, Tuple & tuple, Index<char> * image = nullptr,
- String * error = nullptr);
+ * handle open, then just pass in a null VFSFile and it will be opened for you.
+ */
+PluginHandle * aud_file_find_decoder(const char * filename, bool fast,
+                                     VFSFile & file, String * error = nullptr);
+bool aud_file_read_tag(const char * filename, PluginHandle * decoder,
+                       VFSFile & file, Tuple & tuple,
+                       Index<char> * image = nullptr, String * error = nullptr);
 
-bool aud_file_can_write_tuple (const char * filename, PluginHandle * decoder);
-bool aud_file_write_tuple (const char * filename, PluginHandle * decoder, const Tuple & tuple);
-bool aud_custom_infowin (const char * filename, PluginHandle * decoder);
+bool aud_file_can_write_tuple(const char * filename, PluginHandle * decoder);
+bool aud_file_write_tuple(const char * filename, PluginHandle * decoder,
+                          const Tuple & tuple);
+bool aud_custom_infowin(const char * filename, PluginHandle * decoder);
 
 #endif
