@@ -151,6 +151,7 @@ static const struct
     {"publisher", Tuple::String, -1},
     {"catalog-number", Tuple::String, -1},
     {"lyrics", Tuple::String, -1},
+    {"disc-number", Tuple::Int, -1},
 
     /* fallbacks */
     {nullptr, Tuple::String, -1},
@@ -182,6 +183,7 @@ static const FieldDictEntry field_dict[] = {
     {"copyright", Tuple::Copyright},
     {"date", Tuple::Date},
     {"description", Tuple::Description},
+    {"disc-number", Tuple::Disc},
     {"file-ext", Tuple::Suffix},
     {"file-name", Tuple::Basename},
     {"file-path", Tuple::Path},
