@@ -283,7 +283,7 @@ EXPORT void VFSFile::set_limit_to_buffer(bool limit)
 
 EXPORT Index<char> VFSFile::read_all()
 {
-    constexpr int maxbuf = 16777216;
+    constexpr int maxbuf = 256 * 1024 * 1024;
     constexpr int pagesize = 4096;
 
     Index<char> buf;
