@@ -25,22 +25,30 @@
 
 enum class AudMenuID;
 enum class PluginType;
+class Playlist;
 class PluginHandle;
+struct EqualizerPreset;
 
 /* about.c */
 void audgui_show_about_window ();
 void audgui_hide_about_window ();
 
 /* confirm.c */
-void audgui_confirm_playlist_delete (int playlist);
-void audgui_show_playlist_rename (int playlist);
+void audgui_confirm_playlist_delete (Playlist playlist);
+void audgui_show_playlist_rename (Playlist playlist);
+
+/* eq-preset.c */
+void audgui_show_eq_preset_window ();
+void audgui_import_eq_presets (const Index<EqualizerPreset> & presets);
 
 /* equalizer.c */
 void audgui_show_equalizer_window ();
 void audgui_hide_equalizer_window ();
 
-/* infopopup.c */
-void audgui_infopopup_show (int playlist, int entry);
+/* infopopup.c
+ * libaudgui-gtk.h contains additional function overloads to allow
+ * passing a GtkWindow parent. Use those functions if possible. */
+void audgui_infopopup_show (Playlist playlist, int entry);
 void audgui_infopopup_show_current ();
 void audgui_infopopup_hide ();
 
@@ -49,7 +57,7 @@ void audgui_run_filebrowser (bool open);
 void audgui_hide_filebrowser ();
 
 /* infowin.c */
-void audgui_infowin_show (int playlist, int entry);
+void audgui_infowin_show (Playlist playlist, int entry);
 void audgui_infowin_show_current ();
 void audgui_infowin_hide ();
 
@@ -69,8 +77,8 @@ void audgui_import_playlist ();
 void audgui_export_playlist ();
 
 /* plugin-menu.c */
-void audgui_plugin_menu_add (AudMenuID id, void (* func) (void), const char * name, const char * icon);
-void audgui_plugin_menu_remove (AudMenuID id, void (* func) (void));
+void audgui_plugin_menu_add (AudMenuID id, void (* func) (), const char * name, const char * icon);
+void audgui_plugin_menu_remove (AudMenuID id, void (* func) ());
 
 /* plugin-prefs.c */
 void audgui_show_plugin_about (PluginHandle * plugin);
@@ -86,8 +94,8 @@ void audgui_queue_manager_show ();
 
 /* urilist.c */
 void audgui_urilist_open (const char * list);
-void audgui_urilist_insert (int playlist, int position, const char * list);
-Index<char> audgui_urilist_create_from_selected (int playlist);
+void audgui_urilist_insert (Playlist playlist, int position, const char * list);
+Index<char> audgui_urilist_create_from_selected (Playlist playlist);
 
 /* url-opener.c */
 void audgui_show_add_url_window (bool open);
