@@ -28,6 +28,7 @@
 
 #include <libaudcore/audstrings.h>
 #include <libaudcore/i18n.h>
+#include <libaudcore/interface.h>
 #include <libaudcore/runtime.h>
 
 #include "libaudqt-internal.h"
@@ -49,6 +50,7 @@ static const char * const audqt_defaults[] = {
     "eq_presets_visible", "FALSE",
     "equalizer_visible", "FALSE",
     "queue_manager_visible", "FALSE",
+    "close_jtf_dialog", "TRUE",
 #ifdef _WIN32
     "theme", "dark",
     "icon_theme", "audacious-flat-dark",
@@ -75,8 +77,16 @@ static void load_qt_translations()
         QApplication::installTranslator(&translators[1]);
 }
 
-void set_icon_theme(void)
+void set_icon_theme()
 {
+    // Make sure that ":/icons" is in the theme search path. In Qt 6 it
+    // is added at startup (see QIconLoader::themeSearchPaths()) but in
+    // some cases gets removed later (see QIconLoader::setThemeName()).
+    // This seems to be a regression since Qt 5.
+    auto themePaths = QIcon::themeSearchPaths();
+    if (!themePaths.contains(":/icons"))
+        QIcon::setThemeSearchPaths(themePaths << ":/icons");
+
     QIcon::setThemeName((QString)aud_get_str("audqt", "icon_theme"));
 
     // make sure we have a valid icon theme
@@ -181,10 +191,17 @@ EXPORT void init()
     // to use 9 pt in most places so let's try to do the same.
     QApplication::setFont(QApplication::font("QMenu"));
 #endif
-#ifdef Q_OS_MAC // Mac-specific font tweaks
+#ifdef Q_OS_MAC
+    // Mac-specific font tweaks
     QApplication::setFont(QApplication::font("QSmallFont"), "QDialog");
     QApplication::setFont(QApplication::font("QSmallFont"), "QTreeView");
     QApplication::setFont(QApplication::font("QTipLabel"), "QStatusBar");
+
+    // Handle MacOS dock activation (AppKit applicationShouldHandleReopen)
+    QObject::connect(qapp, &QApplication::applicationStateChanged, [](auto state) {
+        if (state == Qt::ApplicationState::ApplicationActive)
+            aud_ui_show(true);
+    });
 #endif
 }
 
@@ -199,6 +216,7 @@ EXPORT void cleanup()
     log_inspector_hide();
     plugin_prefs_hide();
     prefswin_hide();
+    songwin_hide();
 
     log_cleanup();
 
