@@ -158,11 +158,11 @@ enum
 
 static const Category categories[] = {
     {"applications-graphics", N_("Appearance")},
-    {"audio-volume-medium", N_("Audio")},
+    {"multimedia-volume-control", N_("Audio")},
     {"applications-internet", N_("Network")},
     {"audio-x-generic", N_("Playlist")},
     {"dialog-information", N_("Song Info")},
-    {"applications-system", N_("Plugins")},
+    {"preferences-other", N_("Plugins")},
     {"preferences-system", N_("Advanced")}};
 
 static const TitleFieldTag title_field_tags[] = {
