@@ -27,7 +27,7 @@ void id3_associate_string (Tuple & tuple, Tuple::Field field, const char * data,
 void id3_associate_int (Tuple & tuple, Tuple::Field field, const char * data, int size);
 void id3_associate_length (Tuple & tuple, const char * data, int size);
 void id3_decode_genre (Tuple & tuple, const char * data, int size);
-void id3_decode_comment (Tuple & tuple, const char * data, int size);
+void id3_associate_memo (Tuple & tuple, Tuple::Field field, const char * data, int size);
 void id3_decode_rva (Tuple & tuple, const char * data, int size);
 void id3_decode_txxx (Tuple & tuple, const char * data, int size);
 
