@@ -50,6 +50,7 @@ enum
     ID3_RVA,
     ID3_PIC,
     ID3_LYRICS,
+    ID3_DISC,
     ID3_TAGS_NO
 };
 
@@ -71,7 +72,8 @@ static const char * id3_frames[ID3_TAGS_NO] = {
     "TXX",
     "RVA",
     "PIC",
-    "LYR"
+    "LYR",
+    "TPA",
 };
 
 #pragma pack(push) /* must be byte-aligned */
@@ -284,12 +286,17 @@ bool ID3v22TagModule::read_tag (VFSFile & handle, Tuple & tuple, Index<char> * i
             id3_decode_rva (tuple, & frame[0], frame.len ());
             break;
           case ID3_PIC:
-            if (image)
+            /* we can return only one image, so once we have found a
+             * valid one, don't read any more PIC frames */
+            if (image && !image->len())
                 * image = id3_decode_pic (& frame[0], frame.len ());
             break;
           case ID3_LYRICS:
             id3_associate_memo (tuple, Tuple::Lyrics, & frame[0], frame.len ());
             break;
+          case ID3_DISC:
+            id3_associate_int (tuple, Tuple::Disc, & frame[0], frame.len ());
+            break;
           default:
             AUDDBG ("Ignoring unsupported ID3 frame %s.\n", (const char *) frame.key);
             break;
